require("chartdirector")

class TrackvlegendController < ApplicationController
    include ChartDirector::InteractiveChartSupport

    def index()
        @ctrl_file = File.expand_path(__FILE__)

        # In this example, we simply use random data for the 2 data series.
        r = ChartDirector::RanSeries.new(127)
        data0 = r.getSeries(180, 70, -5, 5)
        data1 = r.getSeries(180, 150, -15, 15)
        timeStamps = r.getDateSeries(180, Time.mktime(2014, 3, 1), 86400)

        # Create a XYChart object of size 640 x 420 pixels
        c = ChartDirector::XYChart.new(640, 420)

        # Add a title to the chart using 20pt Arial font
        c.addTitle("    Plasma Stabilizer Energy Usage", "Arial", 20)

        # Set the plotarea at (55, 60) and of size 560 x 330 pixels, with transparent background and
        # border and light grey (0xcccccc) horizontal grid lines
        c.setPlotArea(55, 60, 560, 330, -1, -1, ChartDirector::Transparent, 0xcccccc)

        # Add a legend box at (55, 30) using horizontal layout, with 10pt Arial Bold as font and
        # transparent background and border.
        c.addLegend(55, 30, false, "Arial Bold", 10).setBackground(ChartDirector::Transparent)

        # Set axis label style to 10pt Arial
        c.xAxis().setLabelStyle("arial.ttf", 10)
        c.yAxis().setLabelStyle("arial.ttf", 10)

        # Set the x and y axis stems to transparent, and the x-axis tick color to grey (0xcccccc)
        c.xAxis().setColors(ChartDirector::Transparent, ChartDirector::TextColor,
            ChartDirector::TextColor, 0xcccccc)
        c.yAxis().setColors(ChartDirector::Transparent)

        # Configure the x-axis tick lengtht to 10 pixels internal to the plot area
        c.xAxis().setTickLength(-10, 0)

        # With the ticks internal to the plot area, the x-axis labels will come very close to the
        # axis stem, so we configure a wider gap.
        c.xAxis().setLabelGap(10)

        # For the automatic axis labels, set the minimum spacing to 80/40 pixels for the x/y axis.
        c.xAxis().setTickDensity(80)
        c.yAxis().setTickDensity(40)

        # Use "mm/yyyy" as the x-axis label format for the first plotted month of a year, and "mm"
        # for other months
        c.xAxis().setMultiFormat(ChartDirector::StartOfYearFilter(), "{value|mm/yyyy} ",
            ChartDirector::StartOfMonthFilter(), "{value|mm}")

        # Add a title to the y axis using dark grey (0x555555) 12pt Arial Bold font
        c.yAxis().setTitle("Energy (kWh)", "arialbd.ttf", 14, 0x555555)

        # Add a line layer with 2-pixel line width
        layer0 = c.addLineLayer(data0, 0xcc0000, "Power Usage")
        layer0.setXData(timeStamps)
        layer0.setLineWidth(2)

        # Add an area layer using semi-transparent blue (0x7f0044cc) as the fill color
        layer1 = c.addAreaLayer(data1, 0x7f0044cc, "Effective Load")
        layer1.setXData(timeStamps)
        layer1.setBorderColor(ChartDirector::SameAsMainColor)

        # Create the WebChartViewer object
        @viewer = ChartDirector::WebChartViewer.new(request, "chart1")

        # Create the image and save it in a session variable
        session[@viewer.getId()] = c.makeChart2(ChartDirector::PNG)

        # Set the chart URL to the viewer
        @viewer.setImageUrl(url_for(:action => "get_session_data", :id => @viewer.getId(),
            :nocache => rand))

        # Output Javascript chart model to the browser to support tracking cursor
        @viewer.setChartModel(c.getJsChartModel())
    end

end

